You can submit new badge ideas on the `fedora-badges
<https://fedorahosted.org/fedora-badges>`_ tracker.

Please report bugs and file issues with التحرير (Tahrir) on `the GitHub issues
tracker <https://github.com/fedora-infra/tahrir/issues>`_.

This project is free software; you can find the `source
<http://github.com/fedora-infra/tahrir>`_ on GitHub.
